VeraCrypt
aboutsummaryrefslogtreecommitdiff
path: root/src/Mount
diff options
context:
space:
mode:
Diffstat (limited to 'src/Mount')
-rw-r--r--src/Mount/Drive_icon_96dpi.bmpbin1206 -> 1658 bytes
-rw-r--r--src/Mount/Drive_icon_mask_96dpi.bmpbin110 -> 110 bytes
-rw-r--r--src/Mount/MainCom.idl12
-rw-r--r--src/Mount/Mount.c61
-rw-r--r--src/Mount/Mount.rc52
-rw-r--r--src/Mount/Mount.vcproj14
-rw-r--r--src/Mount/System_drive_icon_96dpi.bmpbin1206 -> 1658 bytes
-rw-r--r--src/Mount/System_drive_icon_mask_96dpi.bmpbin110 -> 110 bytes
8 files changed, 73 insertions, 66 deletions
diff --git a/src/Mount/Drive_icon_96dpi.bmp b/src/Mount/Drive_icon_96dpi.bmp
index 8c97b566..bb206cbc 100644
--- a/src/Mount/Drive_icon_96dpi.bmp
+++ b/src/Mount/Drive_icon_96dpi.bmp
Binary files differ
diff --git a/src/Mount/Drive_icon_mask_96dpi.bmp b/src/Mount/Drive_icon_mask_96dpi.bmp
index 38a48ccf..9b8ed712 100644
--- a/src/Mount/Drive_icon_mask_96dpi.bmp
+++ b/src/Mount/Drive_icon_mask_96dpi.bmp
Binary files differ
diff --git a/src/Mount/MainCom.idl b/src/Mount/MainCom.idl
index 7d8f60dc..8999d4ec 100644
--- a/src/Mount/MainCom.idl
+++ b/src/Mount/MainCom.idl
@@ -10,17 +10,17 @@ import "wtypes.idl";
import "..\Common\Password.h";
[
- uuid(1770F56C-7881-4591-A179-79B8001C7D42),
- helpstring("TrueCrypt Main UAC Support Library"),
+ uuid(9ACF6176-5FC4-4690-A025-B3306A50EB6A),
+ helpstring("VeraCrypt Main UAC Support Library"),
version(2.4) // Update ComSetup.cpp when changing version number
]
library TrueCryptMainCom
{
[
- uuid(252C9DE6-D4B9-4A59-8A10-9CA73217B3D0),
+ uuid(C786E27C-2801-482c-B45D-D4357B270A29),
object,
oleautomation,
- helpstring("TrueCrypt Main UAC Support Interface")
+ helpstring("VeraCrypt Main UAC Support Interface")
]
interface ITrueCryptMainCom : IUnknown
{
@@ -40,8 +40,8 @@ library TrueCryptMainCom
};
[
- uuid(CECBC0EE-78D9-41E6-BCF1-BC222BB224BA),
- helpstring("TrueCrypt Main UAC Support Coclass")
+ uuid(FE8B3B95-C80C-41f7-830F-FBA271C26F7E),
+ helpstring("VeraCrypt Main UAC Support Coclass")
]
coclass TrueCryptMainCom
{
diff --git a/src/Mount/Mount.rc b/src/Mount/Mount.rc
index 5229c045..82cf6954 100644
--- a/src/Mount/Mount.rc
+++ b/src/Mount/Mount.rc
@@ -43,7 +43,7 @@ IDR_MOUNT_TLB TYPELIB "Mount.tlb"
IDD_PREFERENCES_DLG DIALOGEX 0, 0, 336, 282
STYLE DS_SETFONT | DS_MODALFRAME | DS_FIXEDSYS | DS_CENTER | WS_POPUP | WS_CAPTION | WS_SYSMENU
-CAPTION "TrueCrypt - Preferences"
+CAPTION "VeraCrypt - Preferences"
FONT 8, "MS Shell Dlg", 400, 0, 0x1
BEGIN
CONTROL "Mount volumes as read-only",IDC_PREF_MOUNT_READONLY,
@@ -53,9 +53,9 @@ BEGIN
CONTROL "Enabled",IDC_PREF_BKG_TASK_ENABLE,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,11,44,111,10
CONTROL "Exit when there are no mounted volumes",IDC_CLOSE_BKG_TASK_WHEN_NOVOL,
"Button",BS_AUTOCHECKBOX | WS_TABSTOP,140,44,188,10
- CONTROL "Start TrueCrypt Background Task",IDC_PREF_LOGON_START,
+ CONTROL "Start VeraCrypt Background Task",IDC_PREF_LOGON_START,
"Button",BS_AUTOCHECKBOX | WS_TABSTOP,11,75,126,10
- CONTROL "Mount all device-hosted TrueCrypt volumes",IDC_PREF_LOGON_MOUNT_DEVICES,
+ CONTROL "Mount all device-hosted VeraCrypt volumes",IDC_PREF_LOGON_MOUNT_DEVICES,
"Button",BS_AUTOCHECKBOX | WS_TABSTOP,140,75,188,10
CONTROL "User logs off",IDC_PREF_DISMOUNT_LOGOFF,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,81,104,114,11
CONTROL "Entering power saving mode",IDC_PREF_DISMOUNT_POWERSAVING,
@@ -84,7 +84,7 @@ BEGIN
PUSHBUTTON "Cancel",IDCANCEL,281,262,50,14
GROUPBOX "Windows",IDT_WINDOWS_RELATED_SETTING,4,160,328,52
GROUPBOX "Default Mount Options",IDT_DEFAULT_MOUNT_OPTIONS,4,3,328,26
- GROUPBOX "TrueCrypt Background Task",IDT_TASKBAR_ICON,4,33,328,26
+ GROUPBOX "VeraCrypt Background Task",IDT_TASKBAR_ICON,4,33,328,26
GROUPBOX "Auto-Dismount",IDT_AUTO_DISMOUNT,4,94,328,62
LTEXT "minutes",IDT_MINUTES,289,129,39,10
LTEXT "Dismount all when:",IDT_AUTO_DISMOUNT_ON,9,110,71,17
@@ -94,7 +94,7 @@ END
IDD_VOLUME_PROPERTIES DIALOGEX 60, 30, 284, 186
STYLE DS_SETFONT | DS_MODALFRAME | DS_FIXEDSYS | WS_POPUP | WS_CAPTION | WS_SYSMENU
-CAPTION "TrueCrypt Volume Properties"
+CAPTION "VeraCrypt Volume Properties"
FONT 8, "MS Shell Dlg", 400, 0, 0x1
BEGIN
DEFPUSHBUTTON "OK",IDOK,114,166,55,14
@@ -129,7 +129,7 @@ END
IDD_MOUNT_DLG DIALOGEX 0, 0, 375, 271
STYLE DS_SETFONT | DS_SETFOREGROUND | DS_3DLOOK | DS_FIXEDSYS | DS_CENTER | WS_MINIMIZEBOX | WS_POPUP | WS_CAPTION | WS_SYSMENU
-CAPTION "TrueCrypt"
+CAPTION "VeraCrypt"
MENU IDR_MENU
CLASS "CustomDlg"
FONT 8, "MS Shell Dlg", 0, 0, 0x0
@@ -159,7 +159,7 @@ END
IDD_PASSWORD_DLG DIALOGEX 0, 0, 280, 68
STYLE DS_SETFONT | DS_MODALFRAME | DS_3DLOOK | DS_FIXEDSYS | DS_CENTER | WS_POPUP | WS_VISIBLE | WS_CAPTION
-CAPTION "Enter TrueCrypt Volume Password"
+CAPTION "Enter VeraCrypt Volume Password"
FONT 8, "MS Shell Dlg", 0, 0, 0x0
BEGIN
EDITTEXT IDC_PASSWORD,48,8,153,14,ES_PASSWORD | ES_AUTOHSCROLL
@@ -176,16 +176,16 @@ END
IDD_TRAVELER_DLG DIALOGEX 0, 0, 300, 269
STYLE DS_SETFONT | DS_MODALFRAME | DS_FIXEDSYS | DS_CENTER | WS_POPUP | WS_CAPTION | WS_SYSMENU
-CAPTION "TrueCrypt Traveler Disk Setup"
+CAPTION "VeraCrypt Traveler Disk Setup"
FONT 8, "MS Shell Dlg", 400, 0, 0x1
BEGIN
EDITTEXT IDC_DIRECTORY,17,29,205,13,ES_AUTOHSCROLL
PUSHBUTTON "Browse...",IDC_BROWSE_DIRS,228,28,57,14
- CONTROL "Include TrueCrypt Volume Creation Wizard",IDC_COPY_WIZARD,
+ CONTROL "Include VeraCrypt Volume Creation Wizard",IDC_COPY_WIZARD,
"Button",BS_AUTOCHECKBOX | WS_TABSTOP,19,48,258,10
CONTROL "Do nothing",IDC_AUTORUN_DISABLE,"Button",BS_AUTORADIOBUTTON,15,97,262,10
- CONTROL "&Start TrueCrypt",IDC_AUTORUN_START,"Button",BS_AUTORADIOBUTTON,15,108,262,11
- CONTROL "&Auto-mount TrueCrypt volume (specified below)",IDC_AUTORUN_MOUNT,
+ CONTROL "&Start VeraCrypt",IDC_AUTORUN_START,"Button",BS_AUTORADIOBUTTON,15,108,262,11
+ CONTROL "&Auto-mount VeraCrypt volume (specified below)",IDC_AUTORUN_MOUNT,
"Button",BS_AUTORADIOBUTTON,15,120,262,11
EDITTEXT IDC_VOLUME_NAME,21,157,194,13,ES_AUTOHSCROLL | WS_DISABLED
PUSHBUTTON "Browse...",IDC_BROWSE_FILES,221,156,57,14,WS_DISABLED
@@ -199,7 +199,7 @@ BEGIN
PUSHBUTTON "Close",IDCLOSE,236,249,57,14
GROUPBOX "File Settings",IDT_FILE_SETTINGS,6,7,287,59
GROUPBOX "AutoRun Configuration (autorun.inf)",IDT_AUTORUN,5,70,288,172
- LTEXT "TrueCrypt volume to mount (relative to traveler disk root):",IDT_TRAVELER_MOUNT,21,147,248,8,WS_DISABLED
+ LTEXT "VeraCrypt volume to mount (relative to traveler disk root):",IDT_TRAVELER_MOUNT,21,147,248,8,WS_DISABLED
RTEXT "Mount volume as drive letter:",IDT_MOUNT_LETTER,18,177,99,8,WS_DISABLED
LTEXT "Create traveler disk files at (traveler disk root directory):",IDT_TRAVEL_ROOT,18,19,259,8
GROUPBOX "Mount Settings",IDT_MOUNT_SETTINGS,13,134,272,100,WS_DISABLED
@@ -208,7 +208,7 @@ END
IDD_HOTKEYS_DLG DIALOGEX 0, 0, 381, 239
STYLE DS_SETFONT | DS_MODALFRAME | DS_3DLOOK | DS_FIXEDSYS | DS_CENTER | WS_POPUP | WS_CAPTION | WS_SYSMENU
-CAPTION "TrueCrypt - System-Wide Hot Keys"
+CAPTION "VeraCrypt - System-Wide Hot Keys"
CLASS "CustomDlg"
FONT 8, "MS Shell Dlg", 0, 0, 0x0
BEGIN
@@ -234,7 +234,7 @@ END
IDD_TOKEN_PREFERENCES DIALOGEX 0, 0, 316, 199
STYLE DS_SETFONT | DS_MODALFRAME | DS_FIXEDSYS | DS_CENTER | WS_POPUP | WS_CAPTION | WS_SYSMENU
-CAPTION "TrueCrypt - Security Token Preferences"
+CAPTION "VeraCrypt - Security Token Preferences"
FONT 8, "MS Shell Dlg", 400, 0, 0x1
BEGIN
EDITTEXT IDC_PKCS11_MODULE,16,23,204,13,ES_AUTOHSCROLL
@@ -251,7 +251,7 @@ END
IDD_SYSENC_SETTINGS DIALOGEX 0, 0, 370, 242
STYLE DS_SETFONT | DS_MODALFRAME | DS_FIXEDSYS | DS_CENTER | WS_POPUP | WS_CAPTION | WS_SYSMENU
-CAPTION "TrueCrypt - System Encryption Settings"
+CAPTION "VeraCrypt - System Encryption Settings"
FONT 8, "MS Shell Dlg", 400, 0, 0x1
BEGIN
CONTROL "Do not &show any texts in the pre-boot authentication screen (except the below custom message)",IDC_DISABLE_BOOT_LOADER_OUTPUT,
@@ -271,7 +271,7 @@ END
IDD_PERFORMANCE_SETTINGS DIALOGEX 0, 0, 370, 206
STYLE DS_SETFONT | DS_MODALFRAME | DS_FIXEDSYS | DS_CENTER | WS_POPUP | WS_CAPTION | WS_SYSMENU
-CAPTION "TrueCrypt - Performance Options"
+CAPTION "VeraCrypt - Performance Options"
FONT 8, "MS Shell Dlg", 400, 0, 0x1
BEGIN
CONTROL "",IDC_HW_AES_SUPPORTED_BY_CPU,"Static",SS_LEFTNOWORDWRAP | WS_GROUP,294,21,57,12,WS_EX_CLIENTEDGE
@@ -293,7 +293,7 @@ END
IDD_FAVORITE_VOLUMES DIALOGEX 0, 0, 380, 276
STYLE DS_SETFONT | DS_MODALFRAME | DS_FIXEDSYS | DS_CENTER | WS_POPUP | WS_CAPTION | WS_SYSMENU
-CAPTION "TrueCrypt - Favorite Volumes"
+CAPTION "VeraCrypt - Favorite Volumes"
FONT 8, "MS Shell Dlg", 400, 0, 0x1
BEGIN
CONTROL "",IDC_FAVORITE_VOLUMES_LIST,"SysListView32",LVS_REPORT | LVS_SINGLESEL | LVS_SHOWSELALWAYS | LVS_ALIGNLEFT | LVS_NOSORTHEADER | WS_BORDER | WS_TABSTOP,7,7,366,92
@@ -437,13 +437,13 @@ BEGIN
BEGIN
BLOCK "040904b0"
BEGIN
- VALUE "CompanyName", "TrueCrypt Foundation"
- VALUE "FileDescription", "TrueCrypt"
- VALUE "FileVersion", "7.1a"
- VALUE "LegalTrademarks", "TrueCrypt"
- VALUE "OriginalFilename", "TrueCrypt.exe"
- VALUE "ProductName", "TrueCrypt"
- VALUE "ProductVersion", "7.1a"
+ VALUE "CompanyName", "IDRIX"
+ VALUE "FileDescription", "VeraCrypt"
+ VALUE "FileVersion", "1.0a"
+ VALUE "LegalTrademarks", "VeraCrypt"
+ VALUE "OriginalFilename", "VeraCrypt.exe"
+ VALUE "ProductName", "VeraCrypt"
+ VALUE "ProductVersion", "1.0a"
END
END
BLOCK "VarFileInfo"
@@ -593,7 +593,7 @@ BEGIN
MENUITEM "Beginner's Tutorial", IDM_ONLINE_TUTORIAL
MENUITEM "Frequently Asked Questions", IDM_FAQ
MENUITEM SEPARATOR
- MENUITEM "TrueCrypt Website", IDM_WEBSITE
+ MENUITEM "VeraCrypt Website", IDM_WEBSITE
MENUITEM "Downloads", IDM_TC_DOWNLOADS
MENUITEM "News", IDM_NEWS
MENUITEM "Version History", IDM_VERSION_HISTORY
@@ -615,7 +615,7 @@ END
STRINGTABLE
BEGIN
- IDS_UACSTRING "TrueCrypt"
+ IDS_UACSTRING "VeraCrypt"
END
#endif // English (U.S.) resources
diff --git a/src/Mount/Mount.vcproj b/src/Mount/Mount.vcproj
index 8d6532bb..f2c3f63f 100644
--- a/src/Mount/Mount.vcproj
+++ b/src/Mount/Mount.vcproj
@@ -72,7 +72,7 @@
<Tool
Name="VCLinkerTool"
AdditionalDependencies="comctl32.lib setupapi.lib version.lib ..\Crypto\Debug\crypto.lib"
- OutputFile="$(OutDir)/TrueCrypt.exe"
+ OutputFile="$(OutDir)/VeraCrypt.exe"
LinkIncremental="2"
GenerateManifest="false"
IgnoreAllDefaultLibraries="false"
@@ -104,7 +104,7 @@
/>
<Tool
Name="VCPostBuildEventTool"
- CommandLine="md &quot;..\Debug\Setup Files&quot; 2&gt;NUL:&#x0D;&#x0A;copy Debug\TrueCrypt.exe &quot;..\Debug\Setup Files&quot; &gt;NUL:&#x0D;&#x0A;"
+ CommandLine="md &quot;..\Debug\Setup Files&quot; 2&gt;NUL:&#x0D;&#x0A;copy Debug\VeraCrypt.exe &quot;..\Debug\Setup Files&quot; &gt;NUL:&#x0D;&#x0A;"
/>
</Configuration>
<Configuration
@@ -160,7 +160,7 @@
<Tool
Name="VCLinkerTool"
AdditionalDependencies="comctl32.lib setupapi.lib version.lib ..\Crypto\Release\crypto.lib"
- OutputFile="$(OutDir)/TrueCrypt.exe"
+ OutputFile="$(OutDir)/VeraCrypt.exe"
LinkIncremental="1"
GenerateManifest="false"
IgnoreAllDefaultLibraries="false"
@@ -194,7 +194,7 @@
/>
<Tool
Name="VCPostBuildEventTool"
- CommandLine="copy Release\TrueCrypt.exe &quot;..\Release\Setup Files&quot;"
+ CommandLine="copy Release\VeraCrypt.exe &quot;..\Release\Setup Files&quot;"
/>
</Configuration>
</Configurations>
@@ -559,11 +559,11 @@
>
</File>
<File
- RelativePath="..\Common\TrueCrypt_mounted.ico"
+ RelativePath="..\Common\VeraCrypt_mounted.ico"
>
</File>
<File
- RelativePath="..\Common\TrueCrypt_volume.ico"
+ RelativePath="..\Common\VeraCrypt_volume.ico"
>
</File>
<Filter
@@ -678,7 +678,7 @@
>
</File>
<File
- RelativePath="..\Common\TrueCrypt.ico"
+ RelativePath="..\Common\VeraCrypt.ico"
>
</File>
</Filter>
diff --git a/src/Mount/System_drive_icon_96dpi.bmp b/src/Mount/System_drive_icon_96dpi.bmp
index 5838fb0f..34a6b58b 100644
--- a/src/Mount/System_drive_icon_96dpi.bmp
+++ b/src/Mount/System_drive_icon_96dpi.bmp
Binary files differ
diff --git a/src/Mount/System_drive_icon_mask_96dpi.bmp b/src/Mount/System_drive_icon_mask_96dpi.bmp
index a0439d04..9b8ed712 100644
--- a/src/Mount/System_drive_icon_mask_96dpi.bmp
+++ b/src/Mount/System_drive_icon_mask_96dpi.bmp
Binary files differ
diff --git a/src/Mount/Mount.c b/src/Mount/Mount.c
index 47d16500..74072fd1 100644
--- a/src/Mount/Mount.c
+++ b/src/Mount/Mount.c
@@ -949,7 +949,7 @@ static void LaunchVolCreationWizard (HWND hwndDlg, const char *arg)
PROCESS_INFORMATION pi;
ZeroMemory (&si, sizeof (si));
- strcpy (++tmp, "TrueCrypt Format.exe\"");
+ strcpy (++tmp, "VeraCrypt Format.exe\"");
if (!FileExists(t))
Error ("VOL_CREATION_WIZARD_NOT_FOUND"); // Display a user-friendly error message and advise what to do
@@ -2927,7 +2927,7 @@ BOOL CALLBACK VolumePropertiesDlgProc (HWND hwndDlg, UINT msg, WPARAM wParam, LP
if (bSysEnc)
{
// TrueCrypt Boot Loader version
- ListItemAddW (list, i, GetString ("TC_BOOT_LOADER_VERSION"));
+ ListItemAddW (list, i, GetString ("VC_BOOT_LOADER_VERSION"));
ListSubItemSet (list, i++, 1, (char *) GetUserFriendlyVersionString (BootEncStatus.BootLoaderVersion).c_str());
// Encrypted portion
@@ -3120,12 +3120,12 @@ BOOL CALLBACK TravelerDlgProc (HWND hwndDlg, UINT msg, WPARAM wParam, LPARAM lPa
WaitCursor ();
GetSystemDirectory (sysDir, sizeof (sysDir));
- sprintf (dstPath, "%s\\TrueCrypt", dstDir);
+ sprintf (dstPath, "%s\\VeraCrypt", dstDir);
CreateDirectory (dstPath, NULL);
// Main app
- sprintf (srcPath, "%s\\TrueCrypt.exe", appDir);
- sprintf (dstPath, "%s\\TrueCrypt\\TrueCrypt.exe", dstDir);
+ sprintf (srcPath, "%s\\VeraCrypt.exe", appDir);
+ sprintf (dstPath, "%s\\VeraCrypt\\VeraCrypt.exe", dstDir);
if (!TCCopyFile (srcPath, dstPath))
{
handleWin32Error (hwndDlg);
@@ -3135,8 +3135,8 @@ BOOL CALLBACK TravelerDlgProc (HWND hwndDlg, UINT msg, WPARAM wParam, LPARAM lPa
// Wizard
if (copyWizard)
{
- sprintf (srcPath, "%s\\TrueCrypt Format.exe", appDir);
- sprintf (dstPath, "%s\\TrueCrypt\\TrueCrypt Format.exe", dstDir);
+ sprintf (srcPath, "%s\\VeraCrypt Format.exe", appDir);
+ sprintf (dstPath, "%s\\VeraCrypt\\VeraCrypt Format.exe", dstDir);
if (!TCCopyFile (srcPath, dstPath))
{
handleWin32Error (hwndDlg);
@@ -3145,8 +3145,8 @@ BOOL CALLBACK TravelerDlgProc (HWND hwndDlg, UINT msg, WPARAM wParam, LPARAM lPa
}
// Driver
- sprintf (srcPath, "%s\\truecrypt.sys", appDir);
- sprintf (dstPath, "%s\\TrueCrypt\\truecrypt.sys", dstDir);
+ sprintf (srcPath, "%s\\veracrypt.sys", appDir);
+ sprintf (dstPath, "%s\\VeraCrypt\\veracrypt.sys", dstDir);
if (!TCCopyFile (srcPath, dstPath))
{
handleWin32Error (hwndDlg);
@@ -3154,8 +3154,8 @@ BOOL CALLBACK TravelerDlgProc (HWND hwndDlg, UINT msg, WPARAM wParam, LPARAM lPa
}
// Driver x64
- sprintf (srcPath, "%s\\truecrypt-x64.sys", appDir);
- sprintf (dstPath, "%s\\TrueCrypt\\truecrypt-x64.sys", dstDir);
+ sprintf (srcPath, "%s\\veracrypt-x64.sys", appDir);
+ sprintf (dstPath, "%s\\VeraCrypt\\veracrypt-x64.sys", dstDir);
if (!TCCopyFile (srcPath, dstPath))
{
handleWin32Error (hwndDlg);
@@ -3166,7 +3166,7 @@ BOOL CALLBACK TravelerDlgProc (HWND hwndDlg, UINT msg, WPARAM wParam, LPARAM lPa
{
// Language pack
sprintf (srcPath, "%s\\Language.%s.xml", appDir, GetPreferredLangId ());
- sprintf (dstPath, "%s\\TrueCrypt\\Language.%s.xml", dstDir, GetPreferredLangId ());
+ sprintf (dstPath, "%s\\VeraCrypt\\Language.%s.xml", dstDir, GetPreferredLangId ());
TCCopyFile (srcPath, dstPath);
}
@@ -3187,18 +3187,18 @@ BOOL CALLBACK TravelerDlgProc (HWND hwndDlg, UINT msg, WPARAM wParam, LPARAM lPa
goto stop;
}
- sprintf (autoMount, "TrueCrypt\\TrueCrypt.exe /q background%s%s%s%s /m rm /v %s",
+ sprintf (autoMount, "VeraCrypt\\VeraCrypt.exe /q background%s%s%s%s /m rm /v %s",
drive > 0 ? driveLetter : "",
bExplore ? " /e" : "",
bCacheInDriver ? " /c y" : "",
bMountReadOnly ? " /m ro" : "",
volName);
- fwprintf (af, L"[autorun]\nlabel=%s\nicon=TrueCrypt\\TrueCrypt.exe\n", GetString ("TC_TRAVELER_DISK"));
+ fwprintf (af, L"[autorun]\nlabel=%s\nicon=VeraCrypt\\VeraCrypt.exe\n", GetString ("TC_TRAVELER_DISK"));
fwprintf (af, L"action=%s\n", bAutoMount ? GetString ("MOUNT_TC_VOLUME") : GetString ("IDC_PREF_LOGON_START"));
- fwprintf (af, L"open=%hs\n", bAutoMount ? autoMount : "TrueCrypt\\TrueCrypt.exe");
- fwprintf (af, L"shell\\start=%s\nshell\\start\\command=TrueCrypt\\TrueCrypt.exe\n", GetString ("IDC_PREF_LOGON_START"));
- fwprintf (af, L"shell\\dismount=%s\nshell\\dismount\\command=TrueCrypt\\TrueCrypt.exe /q /d\n", GetString ("DISMOUNT_ALL_TC_VOLUMES"));
+ fwprintf (af, L"open=%hs\n", bAutoMount ? autoMount : "VeraCrypt\\VeraCrypt.exe");
+ fwprintf (af, L"shell\\start=%s\nshell\\start\\command=VeraCrypt\\VeraCrypt.exe\n", GetString ("IDC_PREF_LOGON_START"));
+ fwprintf (af, L"shell\\dismount=%s\nshell\\dismount\\command=VeraCrypt\\VeraCrypt.exe /q /d\n", GetString ("DISMOUNT_ALL_TC_VOLUMES"));
CheckFileStreamWriteErrors (af, dstPath);
fclose (af);
@@ -4242,7 +4242,7 @@ void CreateRescueDisk (void)
char initialDir[MAX_PATH];
SHGetFolderPath (NULL, CSIDL_MYDOCUMENTS, NULL, 0, initialDir);
- if (!BrowseFilesInDir (MainDlg, "OPEN_TITLE", initialDir, szRescueDiskISO, FALSE, TRUE, NULL, L"TrueCrypt Rescue Disk.iso", L"iso"))
+ if (!BrowseFilesInDir (MainDlg, "OPEN_TITLE", initialDir, szRescueDiskISO, FALSE, TRUE, NULL, L"VeraCrypt Rescue Disk.iso", L"iso"))
{
CloseSysEncMutex ();
return;
@@ -5443,7 +5443,7 @@ BOOL CALLBACK MainDialogProc (HWND hwndDlg, UINT uMsg, WPARAM wParam, LPARAM lPa
case TC_APPMSG_SYSENC_CONFIG_UPDATE:
LoadSysEncSettings (hwndDlg);
// The wizard added TrueCrypt.exe to the system startup sequence or performed other operations that
// require us to update our cached settings.
LoadSettings (hwndDlg);
@@ -5764,7 +5764,7 @@ BOOL CALLBACK MainDialogProc (HWND hwndDlg, UINT uMsg, WPARAM wParam, LPARAM lPa
if ((lw == IDOK || lw == IDM_MOUNT_VOLUME || lw == IDM_MOUNT_VOLUME_OPTIONS || lw == IDC_MOUNTALL || lw == IDM_MOUNTALL)
&& LOWORD (GetSelectedLong (GetDlgItem (hwndDlg, IDC_DRIVELIST))) == 0xffff)
{
- MessageBoxW (hwndDlg, GetString ("SELECT_FREE_DRIVE"), L"TrueCrypt", MB_ICONEXCLAMATION);
+ MessageBoxW (hwndDlg, GetString ("SELECT_FREE_DRIVE"), L"VeraCrypt", MB_ICONEXCLAMATION);
return 1;
}
@@ -6967,7 +6967,7 @@ int WINAPI WinMain (HINSTANCE hInstance, HINSTANCE hPrevInstance, char *lpszComm
RegisterRedTick(hInstance);
/* Allocate, dup, then store away the application title */
- lpszTitle = L"TrueCrypt";
+ lpszTitle = L"VeraCrypt";
status = DriverAttach ();
if (status != 0)
@@ -6998,7 +6998,7 @@ BOOL TaskBarIconAdd (HWND hwnd)
// Only one icon may be created
if (TaskBarIconMutex != NULL) return TRUE;
- TaskBarIconMutex = CreateMutex (NULL, TRUE, "TrueCryptTaskBarIcon");
+ TaskBarIconMutex = CreateMutex (NULL, TRUE, "VeraCryptTaskBarIcon");
if (TaskBarIconMutex == NULL || GetLastError () == ERROR_ALREADY_EXISTS)
{
TaskBarIconMutex = NULL;
@@ -7018,7 +7018,7 @@ BOOL TaskBarIconAdd (HWND hwnd)
| LR_SHARED
| (nCurrentOS != WIN_2000 ? LR_DEFAULTCOLOR : LR_VGACOLOR)); // Windows 2000 cannot display more than 16 fixed colors in notification tray
- wcscpy (tnid.szTip, L"TrueCrypt");
+ wcscpy (tnid.szTip, L"VeraCrypt");
return Shell_NotifyIconW (NIM_ADD, &tnid);
}
@@ -8197,7 +8197,7 @@ static BOOL CALLBACK PerformanceSettingsDlgProc (HWND hwndDlg, UINT msg, WPARAM
if (ReadEncryptionThreadPoolFreeCpuCountLimit() != cpuFreeCount)
{
- BootEncObj->WriteLocalMachineRegistryDwordValue ("SYSTEM\\CurrentControlSet\\Services\\truecrypt", TC_ENCRYPTION_FREE_CPU_COUNT_REG_VALUE_NAME, cpuFreeCount);
+ BootEncObj->WriteLocalMachineRegistryDwordValue ("SYSTEM\\CurrentControlSet\\Services\\veracrypt", TC_ENCRYPTION_FREE_CPU_COUNT_REG_VALUE_NAME, cpuFreeCount);
Warning ("SETTING_REQUIRES_REBOOT");
}
@@ -8640,7 +8640,7 @@ void AnalyzeKernelMiniDump (HWND hwndDlg)
if (_abs64 (miniDumpTime.QuadPart - memDumpTime.QuadPart) < 10I64 * 1000 * 1000 * 60 * 5)
{
// Rename MEMORY.DMP file first as it can be deleted by Windows when system crash dialog is closed
- tmpDumpPath = memDumpPath + ".true_crypt.dmp"; // Application name must be mangled to avoid interfering with crash analysis
+ tmpDumpPath = memDumpPath + ".hd_crypt.dmp"; // Application name must be mangled to avoid interfering with crash analysis
if (MoveFile (memDumpPath.c_str(), tmpDumpPath.c_str()))
dumpPath = tmpDumpPath;
@@ -8671,10 +8671,16 @@ void AnalyzeKernelMiniDump (HWND hwndDlg)
if (!IsApplicationInstalled (Is64BitOs() ? "Debugging Tools for Windows (x64)" : "Debugging Tools for Windows (x86)"))
{
+ string sDbgCmd;
if (AskOkCancel ("ASK_DEBUGGER_INSTALL") != IDOK)
return;
- if (!CreateProcess (NULL, (LPSTR) (string ("msiexec.exe /qb /i " TC_APPLINK "&dest=ms-debug-tools-x") + (Is64BitOs() ? "64" : "86")).c_str(),
+ if (Is64BitOs())
+ sDbgCmd = "msiexec.exe /qb /i http://www.idrix.fr/Root/MSDebug/dbg_amd64_6.11.1.404.msi";
+ else
+ sDbgCmd = "msiexec.exe /qb /i http://www.idrix.fr/Root/MSDebug/dbg_x86_6.11.1.404.msi";
+
+ if (!CreateProcess (NULL, (LPSTR) sDbgCmd.c_str(),
NULL, NULL, FALSE, 0, NULL, NULL, &startupInfo, &procInfo))
{
handleWin32Error (hwndDlg);
@@ -8862,7 +8868,7 @@ void AnalyzeKernelMiniDump (HWND hwndDlg)
retAddrs.push_back (s);
}
-
+ /*
char url[MAX_URL_LENGTH];
sprintf (url, TC_APPLINK_SECURE "&dest=syserr-report&os=%s&osver=%d.%d.%d&arch=%s&err=%I64x&arg1=%I64x&arg2=%I64x&arg3=%I64x&arg4=%I64x&flag=%s&drv=%s",
GetWindowsEdition().c_str(),
@@ -8937,6 +8943,7 @@ void AnalyzeKernelMiniDump (HWND hwndDlg)
if (AskYesNoString (msg.c_str()) == IDYES)
ShellExecute (NULL, "open", urlStr.c_str(), NULL, NULL, SW_SHOWNORMAL);
+ */
}
@@ -5443,7 +5443,7 @@ BOOL CALLBACK MainDialogProc (HWND hwndDlg, UINT uMsg, WPARAM wParam, LPARAM lPa
case TC_APPMSG_SYSENC_CONFIG_UPDATE:
LoadSysEncSettings (hwndDlg);
- // The wizard added TrueCrypt.exe to the system startup sequence or performed other operations that
+ // The wizard added VeraCrypt.exe to the system startup sequence or performed other operations that
// require us to update our cached settings.
LoadSettings (hwndDlg);